/* -*- Mode: C; c-basic-offset: 8; tab-width: 8 -*- */
/*
 *  AEWPHelperClient.c
 *
 *  Created by Erik Larsson on 2009-09-04.
 *  Copyright 2009-2010 Tuxera Ltd. All rights reserved.
 *
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <CoreFoundation/CoreFoundation.h>

#include "AEWPHelperClient.h"

#define CFLog(args...) do { CFStringRef string = CFStringCreateWithFormat(kCFAllocatorDefault, NULL, args); CFShow(string); CFRelease(string); } while(0)

#define error(fmt, args...) do { CFLog(CFSTR(fmt), ##args); free(cstrLine); return 0; } while(0)

int readAEWPHelperOutput(FILE *communicationsPipe,
			 AEWPHelperResults *results,
			 void *handlerContext,
			 void (*stdoutHandler)(void*, char*, size_t),
			 void (*stderrHandler)(void*, char*, size_t)) {

	char *currentLine = NULL;
	size_t currentLineSize = 0;

	results->hasPid = 0;
	results->hasChildpid = 0;
	results->hasErrorCode = 0;
	results->hasExitValue = 0;

	while((currentLine = fgetln(communicationsPipe, &currentLineSize)) != NULL) {
		long longValue;
		size_t sizeValue;
		char *cstrLine = calloc(1, currentLineSize+1);
		memcpy(cstrLine, currentLine, currentLineSize);

		if(sscanf(cstrLine, "PID: %ld\n", &longValue) == 1) {
			results->pid = longValue;
			results->hasPid = 1;
		}
		else if(sscanf(cstrLine, "CHILDPID: %ld\n", &longValue) == 1) {
			results->childpid = longValue;
			results->hasChildpid = 1;
		}
		else if(sscanf(cstrLine, "ERROR: %ld %*[^\n]\n", &longValue) == 1) {
			results->errorCode = longValue;
			results->hasErrorCode = 1;
		}
		else if(sscanf(cstrLine, "EXITVALUE: %ld\n", &longValue) == 1) {
			results->exitValue = longValue;
			results->hasExitValue = 1;
		}
		else if(sscanf(cstrLine, "STDOUT: %zd\n", &sizeValue) == 1) {
			char *temp = malloc(sizeValue);
			fread(temp, sizeValue, 1, communicationsPipe);
			currentLine = fgetln(communicationsPipe,
					     &currentLineSize);

			if(currentLineSize != 1 || currentLine[0] != '\n')
				error("STDOUT data chunk didn't end with a "
				      "newline. currentLineSize=%zd "
				      "currentLine[0]=0x%X",
				      currentLineSize, currentLine[0]);

			if(stdoutHandler != NULL)
				stdoutHandler(handlerContext, temp, sizeValue);

			free(temp);
		}
		else if(sscanf(cstrLine, "STDERR: %zd\n", &sizeValue) == 1) {
			char *temp = malloc(sizeValue);
			fread(temp, sizeValue, 1, communicationsPipe);
			currentLine = fgetln(communicationsPipe,
					     &currentLineSize);

			if(currentLineSize != 1 || currentLine[0] != '\n')
				error("STDERR data chunk didn't end with a "
				      "newline. currentLineSize=%zd "
				      "currentLine[0]=0x%X",
				      currentLineSize, currentLine[0]);

			if(stderrHandler != NULL)
				stderrHandler(handlerContext, temp, sizeValue);

			free(temp);
		}
		else {
			error("Unrecognized line: \"%s\"", cstrLine);
		}

		free(cstrLine);
	}

	return 1;
}
