/* -*- Mode: C; c-basic-offset: 8; tab-width: 8 -*- */
/*
 *  AEWPHelperClient.h
 *
 *  Created by Erik Larsson on 2009-09-04.
 *  Copyright 2009 Tuxera Ltd. All rights reserved.
 *
 */

#include <unistd.h>

typedef struct {
	int hasPid;
	pid_t pid;
	
	int hasChildpid;
	pid_t childpid;
	
	int hasErrorCode;
	int errorCode;
	
	int hasExitValue;
	int exitValue;
} AEWPHelperResults;

/**
 * Reads and parses the output of an AEWPHelper process. This function will not
 * return until 1) AEWPHelper exits normally or with an error condition, or
 * 2) if any error is encountered during parsing.
 *
 * @param communicationsPipe the standard output stream of the AEWPHelper
 * process.
 * @param results (out) a pointer to an AEWPHelperResults struct which stores
 * relevant information sent by AEWPHelper.
 * @param handlerContext an optional pointer that will be passed as the first
 * argument to the stdout and stderr handlers.
 * @param stdoutHandler a callback that receives the executing tool's standard
 * output stream. This parameter may be NULL, in which case the stream data is
 * discarded.
 * @param stderrHandler a callback that receives the executing tool's standard
 * error stream. This parameter may be NULL, in which case the stream data is
 * discarded.
 * @return TRUE (1) if the read method completed successfully, and FALSE (0) if
 * an internal error condition occurred. (Whether or not the AEWPHelper utility
 * completed successfully can be read out from the AEWPHelperResults.)
 */
int readAEWPHelperOutput(FILE *communicationsPipe, AEWPHelperResults *results,
			 void *handlerContext,
			 void (*stdoutHandler)(void*, char*, size_t),
			 void (*stderrHandler)(void*, char*, size_t));
