#!/bin/bash

Match () {
    local SUBFILE="$1"
    local DIRNAME="$2"
    CMPRES=`expr "${SUBFILE}" : "${DIRNAME}"`
    RETVAL="$?"
    if [ "${RETVAL}" -eq 0 ]; then
	if [ -d "${SUBFILE}" ]; then
	    echo "`pwd`/${SUBFILE}/"
	    rm -r "${SUBFILE}"
	else
	    echo "`pwd`/${SUBFILE}"
	    rm "${SUBFILE}"
	fi
    elif [ "${RETVAL}" -eq 1 ]; then
	if [ -d "${SUBFILE}" ]; then
	    RecursiveRmdir "${DIRNAME}" "${SUBFILE}"
	fi
    fi
}

RecursiveRmdir () {
    local DIRNAME="$1"
    #local DIRNAMELEN="${#DIRNAME}"
    shift 1
    while [ ! $# -eq 0 ]; do
	local FILE="$1"
	shift 1
	
	if [ -d "${FILE}" ]; then
	    
	    pushd "${FILE}" > /dev/null
	    
	    for SUBFILE in .*; do
		if [ ! "${SUBFILE}" = ".." ] && [ ! "${SUBFILE}" = "." ]; then
		    Match "${SUBFILE}" "${DIRNAME}"
		fi
	    done		    
	    
	    for SUBFILE in *; do
		if [ ! "${SUBFILE}" = "*" ]; then
		    Match "${SUBFILE}" "${DIRNAME}"
		fi
	    done
	    
	    popd > /dev/null
	else
	    Match "${FILE}" "${DIRNAME}"
	fi
    done
}

CheckForErrors() {
    _ERRVAL=$1
    if [ ! "${_ERRVAL}" -eq 0 ]; then
	echo "There were errors... aborting."
	exit ${_ERRVAL}
    fi
}

TEMPDIR=.srcdisttemp~
TARGETPREFIX=Releases/current-src

echo "Cleaning temp dir..."
rm -r $TEMPDIR
mkdir $TEMPDIR
CheckForErrors $?
mkdir $TEMPDIR/NTFS-3G_PrefPane
CheckForErrors $?

echo "Copying files..."
cp * $TEMPDIR/NTFS-3G_PrefPane
#CheckForErrors $?
cp -R English.lproj $TEMPDIR/NTFS-3G_PrefPane
CheckForErrors $?
cp -R src $TEMPDIR/NTFS-3G_PrefPane
CheckForErrors $?
cp -R include $TEMPDIR/NTFS-3G_PrefPane
CheckForErrors $?
mkdir ${TEMPDIR}/NTFS-3G_PrefPane/NTFS-3G_PrefPane.xcodeproj
CheckForErrors $?
cp NTFS-3G_PrefPane.xcodeproj/project.pbxproj $TEMPDIR/NTFS-3G_PrefPane/NTFS-3G_PrefPane.xcodeproj
CheckForErrors $?

echo "Removing CVS directories..."
RecursiveRmdir "^CVS$" "$TEMPDIR"
CheckForErrors $?
echo "Removing emacs backup files (*~)..."
RecursiveRmdir ".*~$" "$TEMPDIR"
CheckForErrors $?
echo "Removing emacs temporary files (#*#)..."
RecursiveRmdir "^#.*#$" "$TEMPDIR"
CheckForErrors $?
echo "Removing Thumbs.db files..."
RecursiveRmdir "^Thumbs\.db$" "$TEMPDIR"
CheckForErrors $?
echo "Removing .DS_Store files..."
RecursiveRmdir "^\.DS_Store$" "$TEMPDIR"
CheckForErrors $?
echo "Removing .cvsignore files..."
RecursiveRmdir "^\.cvsignore$" "$TEMPDIR"
CheckForErrors $?

echo "Setting execute permissions for shell scripts..."
chmod a+x $TEMPDIR/NTFS-3G_PrefPane/*.sh
CheckForErrors $?

echo "Building tar.bz2 file..."
cd $TEMPDIR
rm -f ../${TARGETPREFIX}.tar ../${TARGETPREFIX}.tar.bz2
tar cvf ../${TARGETPREFIX}.tar *
CheckForErrors $?
bzip2 -9 ../${TARGETPREFIX}.tar
CheckForErrors $?
cd ..

echo "Done! Generated file: ${TARGETPREFIX}.tar.bz2"
