/*-
 * Copyright (C) 2008-2010 Erik Larsson
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */

/*
 *  EnsureDirectory.c
 *  NTFS-3G_PrefPane
 *
 *  Created by Erik Larsson on 2009-01-06.
 *
 */

#include <stdio.h>
#include <stdlib.h>
#include <sys/stat.h>
#include <errno.h>

#define error(msg, args...) \
	do { \
		fprintf(stderr, msg, ##args); \
		fprintf(stderr, "\n"); \
		exit(1); \
	} while(0)

int main(int argc, char **argv) {
	int retval = 1;
	
	if(argc != 2) {
		error("Invalid number of arguments. (got: %d, required: 1)",
				(argc-1));
	}
	else {
		char *path = argv[1];
		struct stat stbuf;
		
		int res = stat(path, &stbuf);
		if(res == 0) {
			if((stbuf.st_mode & S_IFDIR) != 0) {
				retval = 0;
			}
			else
				error("\"%s\" is not a directory! st_mode=0x%X", path, stbuf.st_mode);
		}
		else {
			if(mkdir(path, S_IRWXU | S_IRWXG | S_IRWXO) == 0) {
				retval = 0;
			}
			else
				error("Could not mkdir \"%s\". errno=%d", path, errno);
		}
	}
	
	return retval;
}