/*-
 * Copyright (C) 2008-2010 Erik Larsson
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */

/*
 *  GetMountFlags.c
 *  NTFS-3G_PrefPane
 *
 *  Created by Erik Larsson on 2009-01-07.
 *
 */

#include <stdio.h>
#include <stdlib.h>
#include <errno.h>
#include <sys/mount.h>

#define error(msg, args...) \
	do { \
		fprintf(stderr, msg, ##args); \
		fprintf(stderr, "\n"); \
		exit(1); \
	} while(0)

static void printMountFlags(long flags, char *prefix, FILE *out) {

	if((flags & MNT_RDONLY) != 0)
		fprintf(out, "%sMNT_RDONLY\n", prefix);
    if((flags & MNT_SYNCHRONOUS) != 0)
		fprintf(out, "%sMNT_SYNCHRONOUS\n", prefix);
    if((flags & MNT_NOEXEC) != 0)
		fprintf(out, "%sMNT_NOEXEC\n", prefix);
    if((flags & MNT_NOSUID) != 0)
		fprintf(out, "%sMNT_NOSUID\n", prefix);
    if((flags & MNT_NODEV) != 0)
		fprintf(out, "%sMNT_NODEV\n", prefix);
    if((flags & MNT_UNION) != 0)
		fprintf(out, "%sMNT_UNION\n", prefix);
    if((flags & MNT_ASYNC) != 0)
		fprintf(out, "%sMNT_ASYNC\n", prefix);
    if((flags & MNT_EXPORTED) != 0)
		fprintf(out, "%sMNT_EXPORTED\n", prefix);
    if((flags & MNT_QUOTA) != 0)
		fprintf(out, "%sMNT_QUOTA\n", prefix);
    if((flags & MNT_ROOTFS) != 0)
		fprintf(out, "%sMNT_ROOTFS\n", prefix);
    if((flags & MNT_DOVOLFS) != 0)
		fprintf(out, "%sMNT_DOVOLFS\n", prefix);
    if((flags & MNT_DONTBROWSE) != 0)
		fprintf(out, "%sMNT_DONTBROWSE\n", prefix);
    if((flags & MNT_UNKNOWNPERMISSIONS) != 0)
		fprintf(out, "%sMNT_UNKNOWNPERMISSIONS\n", prefix);
    if((flags & MNT_AUTOMOUNTED) != 0)
		fprintf(out, "%sMNT_AUTOMOUNTED\n", prefix);
    if((flags & MNT_JOURNALED) != 0)
		fprintf(out, "%sMNT_JOURNALED\n", prefix);
    if((flags & MNT_DEFWRITE) != 0)
		fprintf(out, "%sMNT_DEFWRITE\n", prefix);	
}

int main(int argc, char **argv) {

	if(argc != 2) {
		error("Invalid number of arguments. (got: %d, required: 1)",
				(argc-1));
	}
	else {
		char *path = argv[1];
		struct statfs buf;

		int res = statfs(path, &buf);
		if(res == 0) {
			printMountFlags(buf.f_flags, "", stdout);
			exit(0);
		}
		else {
			error("Could not statfs \"%s\". errno=%d", path, errno);
		}
	}
}
