/*-
 * Copyright (C) 2008-2010 Erik Larsson
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */

/*
 *  ListDriverMounts.c
 *  NTFS-3G_PrefPane
 *
 *  Created by Erik Larsson on 2008-12-20.
 *
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <errno.h>
#include <sys/mount.h>

#if defined(BUILDTARGET_TIGER)
#define __IS_TIGER
#elif !defined(BUILDTARGET_LEOPARD)
#error "No BUILDTARGET defined."
#endif

/*
 * This utility is a helper to the preference pane.
 * It lists all the currently mounted NTFS-3G or Tuxera NTFS file systems to stdout.
 *
 * The previous "special" error handling system has been replaced by an AEWPHelper
 * solution, so this utility now returns 1 on error with an error message printed to
 * stderr,
 */

#if 0
#define FUSEFS_PREFIX "fusefs_txantfs"
#define FUSEFS_STRLEN 14
#define FUSEFS_SUBTYPE 0
#else
#define FUSEFS_PREFIX "fusefs"
#define FUSEFS_STRLEN 6
#define FUSEFS_SUBTYPE 8
#endif

#define error(msg, args...) \
	do { \
		fprintf(stderr, msg, ##args); \
		fprintf(stderr, "\n"); \
		exit(1); \
	} while(0)

int main(int argc, char **argv) {
#ifdef __IS_TIGER
	struct statfs *mntbufp;
#else
	struct statfs64 *mntbufp;
#endif
	int mountedFileSystems, i;

	if(geteuid() != 0)
		error("Not running as root! (uid=%d euid=%d gid=%d)",
			  getuid(), geteuid(), getgid());

#ifdef __IS_TIGER
	mountedFileSystems = getmntinfo(&mntbufp, MNT_WAIT);
#else
	mountedFileSystems = getmntinfo64(&mntbufp, MNT_WAIT);
#endif
	if(mountedFileSystems <= 0)
		error("Error in getmntinfo: %d (%s)", errno, strerror(errno));

	for(i = 0; i < mountedFileSystems; ++i) {
#ifdef __IS_TIGER
		struct statfs cur_statfs = mntbufp[i];
#else
		struct statfs64 cur_statfs = mntbufp[i];
#endif
		if(strncmp(cur_statfs.f_fstypename, FUSEFS_PREFIX, FUSEFS_STRLEN) == 0 &&
#ifdef __IS_TIGER
		   cur_statfs.f_reserved1 == FUSEFS_SUBTYPE)
#else
		   cur_statfs.f_fssubtype == FUSEFS_SUBTYPE)
#endif
		{
			fprintf(stdout, "%s\n", cur_statfs.f_mntonname);
			if((cur_statfs.f_flags & MNT_RDONLY) != 0)
				fprintf(stdout, "  readonly\n");
			else
				fprintf(stdout, "  readwrite\n");
		}
	}

	exit(0);
	return 0;
}
