/*
 * Copyright (c) 2005-2006 Michele Balistreri
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE. 
 */

/*
 * Modified slightly 2009-11-26 by Erik Larsson, Tuxera Ltd. for
 * usage in the Tuxera NTFS for Mac preference pane.
 */

#import "NTFSDriverSingleLineFormatter.h"

@implementation NTFSDriverSingleLineFormatter

+ (NSCharacterSet *)newlineCharacterSet;
{
    static NSCharacterSet *newlineCharacterSet = nil;
    if (nil == newlineCharacterSet) 
	{
		// This will be a character set with all newline characters (including the weird Unicode ones)
		CFMutableCharacterSetRef newlineCFCharacterSet = NULL;
		// get all whitespace characters (does not include newlines)
		newlineCFCharacterSet = CFCharacterSetCreateMutableCopy(CFAllocatorGetDefault(), CFCharacterSetGetPredefined(kCFCharacterSetWhitespace));
		// invert the whitespace-only set to get all non-whitespace chars (the inverted set will include newlines)
		CFCharacterSetInvert(newlineCFCharacterSet);
		// now get only the characters that are common to kCFCharacterSetWhitespaceAndNewline and our non-whitespace set
		CFCharacterSetIntersect(newlineCFCharacterSet, CFCharacterSetGetPredefined(kCFCharacterSetWhitespaceAndNewline));
		newlineCharacterSet = [(id)newlineCFCharacterSet copy];
    }
    return newlineCharacterSet;
}

- (NSString *)stringForObjectValue:(id)anObject
{
	NSString *returnString = @"";
	NSString *tmpString = nil;
	
	NSScanner *scanner = [NSScanner scannerWithString:anObject];
	while([scanner scanUpToCharactersFromSet:[NTFSDriverSingleLineFormatter newlineCharacterSet] intoString:&tmpString])
		returnString = [returnString stringByAppendingString:tmpString];

	return returnString;
}

- (BOOL)getObjectValue:(id *)anObject forString:(NSString *)string errorDescription:(NSString **)error
{
	NSScanner *scanner = [NSScanner scannerWithString:string];
	NSString *tmpString = nil;
	*anObject = @"";
	while([scanner scanUpToCharactersFromSet:[NTFSDriverSingleLineFormatter newlineCharacterSet] intoString:&tmpString])
		*anObject = [*anObject stringByAppendingString:tmpString];
	return YES;
}

- (BOOL)isPartialStringValid:(NSString *)partialString newEditingString:(NSString **)newString errorDescription:(NSString **)error
{
	if([partialString rangeOfCharacterFromSet:[NTFSDriverSingleLineFormatter newlineCharacterSet]].location == NSNotFound)
		return YES;
	
	NSScanner *scanner = [NSScanner scannerWithString:partialString];
	NSString *tmpString = nil;
	*newString = @"";
		
	while([scanner scanUpToCharactersFromSet:[NTFSDriverSingleLineFormatter newlineCharacterSet] intoString:&tmpString])
		*newString = [*newString stringByAppendingString:tmpString];
	
	return NO;
}
@end
