#!/bin/sh -x

# Function definitions

ExitCheck() {
    _EXITVAL="$1"
    #echo "ExitCheck: _EXITVAL=${_EXITVAL}"
    if [ ${_EXITVAL} -ne 0 ]; then
	echo "There were errors..."
	exit ${_EXITVAL}
    fi
}

ProcessComponent() {
    _COMPONENT_NAME="$1"
    _COMPONENT_DIR="${DIST_DIR}/${_COMPONENT_NAME}"
    _COMPONENT_BUILD_DIR="${BUILD_DIR}/${_COMPONENT_NAME}"

    echo "Processing component \"${_COMPONENT_NAME}\"..."
    mkdir "${_COMPONENT_BUILD_DIR}" ; ExitCheck $?
    "${_COMPONENT_DIR}/build.sh" "${_COMPONENT_DIR}" "${_COMPONENT_BUILD_DIR}" "${ROOT_DIR}"
    _BUILD_SH_RETVAL=$?
    echo "Retval from build.sh: ${_BUILD_SH_RETVAL}"
    return ${_BUILD_SH_RETVAL}
}

# Entry point

# DIST_DIR is where the sources for this distribution version are maintained.
DIST_DIR="$1"
if [ -z "${DIST_DIR}" ]; then
    DIST_DIR="`pwd`/`dirname $0`"
fi

# TMP_DIR is a temporary storage place where the build results and the final
# package root are placed.
TMP_DIR="$2"
if [ -z "${TMP_DIR}" ]; then
    TMP_DIR="`pwd`/.buildroot_tmp"
    if [ -d "${TMP_DIR}" ]; then
	echo "Cleaning build dir... (you may be asked for your password)"
	sudo rm -rf "${TMP_DIR}" ; ExitCheck $?
    fi
    mkdir "${TMP_DIR}" ; ExitCheck $?
fi

BUILD_DIR="${TMP_DIR}/build"
ROOT_DIR="${TMP_DIR}/root"

# Create all needed dirs
mkdir "${BUILD_DIR}" ; ExitCheck $?
mkdir -m 0755 "${ROOT_DIR}" ; ExitCheck $?
sudo chown root:wheel "${ROOT_DIR}" ; ExitCheck $?

# Process each component
ProcessComponent "libublio" ; ExitCheck $?
ProcessComponent "ntfs-3g" ; ExitCheck $?
ProcessComponent "ntfsprogs" ; ExitCheck $?
ProcessComponent "ntfs-3g_prefpane" ; ExitCheck $?
ProcessComponent "fuse_wait" ; ExitCheck $?
ProcessComponent "ntfs-3g_daemon" ; ExitCheck $?
ProcessComponent "fsbundle" ; ExitCheck $?
ProcessComponent "ntfs-3g_confirm_mount" ; ExitCheck $?
ProcessComponent "newfs_ntfs-3g" ; ExitCheck $?
ProcessComponent "showdialog" ; ExitCheck $?

# Create some additional symlinks
sudo mkdir -m 0755 "${ROOT_DIR}/sbin" ; ExitCheck $?
sudo ln -s "../System/Library/Filesystems/ntfs-3g.fs/ntfs-3g.util" "${ROOT_DIR}/sbin/mount_ntfs-3g" ; ExitCheck $?
sudo ln -s "../System/Library/Filesystems/ntfs-3g.fs/Support/newfs_ntfs-3g" "${ROOT_DIR}/sbin/newfs_ntfs-3g" ; ExitCheck $?
sudo chown -R root:wheel "${ROOT_DIR}/sbin" ; ExitCheck $?

exit 0