#!/bin/bash

DRIVERNAME="NTFS-3G"
PACKAGENAME="NTFS-3G"
PACKAGEID="org.catacombae.ntfs-3g_package"
FSBUNDLENAME="ntfs-3g"
FSBUNDLEDIR="/System/Library/Filesystems/${FSBUNDLENAME}.fs"
PREFPANEDIR="/Library/PreferencePanes/${DRIVERNAME}.prefPane"
RECEIPT="${FSBUNDLEDIR}/Support/Archive.bom"

error() {
    echo "There were errors... aborting."
    exit 1
}

checkForErrors() {
    _ERRVAL=$1
    if [ ! "${_ERRVAL}" -eq 0 ]; then error; fi
}

EFFECTIVE_UID=${EUID} #`id -u`
if [ ${EFFECTIVE_UID} -ne 0 ]; then
    echo "ERROR: Not running as root! (UID: ${UID} EUID: ${EUID})"
    exit 100
fi

if [ ! -f "${RECEIPT}" ]; then
    echo "Receipt \"${RECEIPT}\" not found... aborting."
    exit 101
fi

echo "Removing package files..."

sh -c "lsbom -fls \"${RECEIPT}\" | colrm 1 1 | sed \"s/^/\\\"/\" | sed \"s/$/\\\"/\" | xargs rm -v"
checkForErrors $?

if [ -d "${FSBUNDLEDIR}" ]; then
    echo "Removing file system bundle directory..."

    rm -rfv "${FSBUNDLEDIR}"
    checkForErrors $?
fi

if [ -d "${PREFPANEDIR}" ]; then
    echo "Removing ${DRIVERNAME} preference pane directory..."

    rm -rfv "${PREFPANEDIR}"
    checkForErrors $?
fi

if [ "${DRIVERNAME}" == "NTFS-3G" ]; then
    # Remove additional directories that are known to have been created by the
    # NTFS-3G installer.

    if [ -d "/usr/local/include/ntfs-3g" ]; then
	echo "Removing libntfs-3g include dir..."

	rm -rfv "/usr/local/include/ntfs-3g"
	checkForErrors $?
    fi

    if [ -d "/usr/local/include/ntfs" ]; then
	echo "Removing libntfs include dir..."

	rm -rfv "/usr/local/include/ntfs"
	checkForErrors $?
    fi

    if [ -d "/usr/local/share/doc/ntfs-3g" ]; then
	echo "Removing ntfs-3g doc dir..."

	rm -rfv "/usr/local/share/doc/ntfs-3g"
	checkForErrors $?
    fi

    if [ -d "/usr/local/share/doc/libublio" ]; then
	echo "Removing libublio doc dir..."

	rm -rfv "/usr/local/share/doc/libublio"
	checkForErrors $?
    fi
fi

# Remove all package receipt files.

if [ -d "/Library/Receipts/${PACKAGENAME}.pkg" ]; then
    echo "Removing package receipt..."

    rm -rfv "/Library/Receipts/${PACKAGENAME}.pkg"
    checkForErrors $?
fi

if [ -f "/var/db/receipts/${PACKAGEID}.bom" ]; then
    echo "Removing package receipt bom file..."

    rm -fv "/var/db/receipts/${PACKAGEID}.bom"
    checkForErrors $?
fi

if [ -f "/var/db/receipts/${PACKAGEID}.plist" ]; then
    echo "Removing package receipt plist file..."

    rm -fv "/var/db/receipts/${PACKAGEID}.plist"
    checkForErrors $?
fi

echo "Done."
exit 0
